@@ -1,4 +1,4 @@
-VERSION = "0.0.22"
+VERSION = "0.0.24"
 SUPPORTED_CLOUD_PROVIDERS = ["aws", "azure", "gcloud"]
 DEFAULT_AWS_BUCKET_REGION = "us-west-2"
 LIST_OF_VARIABLES_FILES = ["vars.tf", "variable.tf", "variables.tf"]
@@ -36,7 +36,7 @@ Terraform remote state wrapper package
 --------------------------------------
 Usage: Set below env variables to begin (more information: https://github.com/tomarv2/tfremote):
 TF_WORKSPACE_FILE_LOCATION
-aws: TF_AWS_BUCKET, TF_AWS_PROFILE or , TF_AWS_BUCKET_REGION=us-west-2
+aws: TF_AWS_BUCKET, TF_AWS_BUCKET_REGION=us-west-2, TF_AWS_PROFILE or AWS_ACCESS_KEY_ID and AWS_SECRET_ACCESS_KEY
 azure: TF_AZURE_STORAGE_ACCOUNT, TF_AZURE_CONTAINER, ARM_ACCESS_KEY
 gcloud: TF_GCLOUD_BUCKET, TF_GCLOUD_CREDENTIALS
 """
